@@ -44,9 +44,13 @@ extern int admincount(void);
 extern int loadconf(char *);
 extern int parseconf(char *);
 extern int getadmins(void);
+extern int getadminauhteds(void);
 extern int getusers(struct channel *);
+extern int getuserauhteds(struct channel *);
 extern int updateadmints(void);
+extern int updateadminauthedsts(void);
 extern int updateuserts(struct channel *);
+extern int updateuserauthedsts(struct channel *);
 extern int initenv(void);
 extern int burstjoins(struct channel *);
 extern int isq(char *);
@@ -211,7 +215,7 @@ extern void quit(void);
 extern void parsectcp(char *, char *, int, char *);
 extern void nstats(struct channel *, char *, int, char *);
 extern void wall(struct channel *, char *, char *, char *);
-extern void cleanautheds(struct channel *, int);
+extern void cleanautheds(struct channel *, int, int);
 extern void listchanusers(void);
 extern void timed_del(struct timed *);
 extern void mmode_del(struct channel *, struct mmode *);
