@@ -34,9 +34,10 @@ int serverconnection(void);
 int registerconnection(void);
 int handleserverdata(void);
 int processtimeds(void);
+int processactions(struct timed *);
 void establishconnection(void);
 void reconnect(void);
-int processactions(struct timed *);
+void proxysetup(void);
 
 void establishconnection()
 {
@@ -272,6 +273,7 @@ int serverconnection()
 		close(mystate->sockfd);
 		return OER_SERVERCONNECTION_ERR_GETSERVER_RETRY;
 	}
+	mystate->current_server->registerconnection_start = mystate->now;
 	mystate->current_server->used = 1;
 #ifdef DEBUG
 	oer_debug(OER_DEBUG_INFO, "serverconnection->using server %s port %d\n", mystate->current_server->serverhost, mystate->current_server->serverport);
@@ -314,6 +316,7 @@ int serverconnection()
 		close(mystate->sockfd);
 		return OER_SERVERCONNECTION_ERR_CONNECT;
 	}
+	proxysetup();
 	mystate->current_server->connected = 1;
 	mystate->current_server->linkup = mystate->now;
 	mystate->current_server->rx = 0;
@@ -343,6 +346,9 @@ int registerconnection()
            && mystate->current_server->registered.done) {
                 return OER_REGISTERCONNECTION_EVERYTHING_OK;
         }
+	if((mystate->now - mystate->current_server->registerconnection_start) > OER_REGISTERCONNECTION_TIMEOUT) {
+                return OER_REGISTERCONNECTION_TIMEOUT;
+        }
 	if(!mystate->current_server->registered.begin) {
                 /* BEGIN */
 #ifdef DEBUG
@@ -459,7 +465,7 @@ int handleserverdata()
 	if((index(mystate->flags, (int)'l') != NULL) && (strstr(mystate->state, "+ro") == NULL)) {
 		/* it doesn't matter if logging fails */
 		mysql_real_escape_string(&mystate->mysqldb.mysqldbconn, mysql_safe_str1, stringbuffer, strlen(stringbuffer));
-		oer_doquery("handleserverdata", OER_DEBUG_NOISE, "INSERT INTO raw VALUES (%lu, '%s', '%s')", mystate->now, mystate->ident, mysql_safe_str1);
+		oer_doquery("handleserverdata", OER_DEBUG_NOISE, "INSERT INTO oer_raw VALUES (%lu, '%s', '%s')", mystate->now, mystate->ident, mysql_safe_str1);
 	}
 	if((ptr = (char *) strstr(stringbuffer, "PING :")) != NULL) {
 		snprintf(pong, STRINGLEN, "PONG :%s\n", ptr + 6);
@@ -606,6 +612,9 @@ int processactions(struct timed *t)
         case OER_TIMED_PRIORITY_PRIVMSG:
                 mystate->last_action.barrier += 1 + (strlen(t->command) / 50);
                 break;
+        case OER_TIMED_PRIORITY_ADVERT:
+                mystate->last_action.barrier += 2 + (strlen(t->command) / 25);
+                break;
 	case OER_TIMED_PRIORITY_NORMAL:
         case OER_TIMED_PRIORITY_CHANNEL_HANDLING:
         case OER_TIMED_PRIORITY_CHANNEL_PROTECTION:
@@ -618,3 +627,22 @@ int processactions(struct timed *t)
         }
         return 1;
 }
+
+void proxysetup()
+{
+	char stringbuffer[STRINGLEN + 1];
+#ifdef DEBUG
+	oer_debug(OER_DEBUG_NOISE, "proxysetup()\n");
+#endif
+	if(strlen(mystate->proxysetup)) {
+		snprintf(stringbuffer, STRINGLEN, "%s\n", mystate->proxysetup);
+#ifdef DEBUG
+		oer_debug(OER_DEBUG_INFO, "proxysetup->%s", stringbuffer);
+#endif
+		if(write(mystate->sockfd, stringbuffer, strlen(stringbuffer)) < 0) {
+#ifdef DEBUG
+			oer_debug(OER_DEBUG_ERROR, "proxysetup->write failed: %s\n", strerror(errno));
+#endif
+		}
+	}
+}
