@@ -364,7 +364,7 @@ enum OER_FLAGS_TYPE {
 details possibly available on the oer+MySQL console"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
 #define OER_UNKNOWN "unknown"
-#define OER_COPYRIGHT1 "oer+MySQL version 1.0-34, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer+MySQL version 1.0-35, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer+MySQL comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -443,6 +443,7 @@ struct botuser {
 
 struct authed {
 	time_t at;
+	int forced_logoff;
 	char *userhost;
 	char *handle;
 	struct authed *prev;
@@ -579,6 +580,7 @@ struct channel {
 	time_t last_quote;
 	time_t join_ts;
 	time_t userts;
+	time_t userauthedsts;
 	time_t requestop;
 	struct join *joins;
 	struct part *parts;
@@ -634,6 +636,7 @@ struct state {
 	time_t startup;
 	time_t postnj_checks_at;
 	time_t admints;
+	time_t adminauthedsts;
 	time_t last_linenoise;
 	time_t last_gn;
 	time_t last_ts_check;
